using AutoScan;
using Microsoft.Extensions.Logging;
using Telegram.Bots.Types;

namespace CasaBotApp.Extensions;

public static class CommandRegister
{
    public static void RegisterCommands(BotHandler botHandler, AutoScanApp autoScanApp)
    {
        botHandler.RegisterCommand(new BotCommand
        {
            Command = "/soyandre",
            Description = "Soy Andre",
            Action = async (message, ctx) =>
            {
                await ctx.Responder(message, "Hola vida, te amo mucho ❤️");
            }
        });
        botHandler.RegisterCommand(new BotCommand
        {
            Command = "/startScan",
            Description = "Start a scan of last night images",
            Action = async (message, ctx) =>
            {
                await ctx.Responder(message, "Starting scan 🔍📼");
                await autoScanApp.StartNewScan();
            }
        });
        botHandler.RegisterCommand(new BotCommand
        {
            Command = "/lastScan",
            Description = "Send the images from the last scan",
            Action = async (message, ctx) =>
            {
                var images = autoScanApp.GetLastScanPictures();
                if (images.Length == 0)
                {
                    await ctx.Responder(message, "No images found");
                    return;
                }
                await botHandler.SendPhotos(message.Chat.Id, images);
            }
        });
        
        botHandler.OnReply = async msg =>
        {
            var originalMsg = msg.ReplyToMessage;

            // Check if the original message is a photo and has a caption
            if (originalMsg is not PhotoMessage photoMessage || photoMessage.Caption is null)
                return;
            
            var videoPath = autoScanApp.GetVideoPath(photoMessage.Caption);
            if (string.IsNullOrEmpty(videoPath))
                return;
            
            await botHandler.SendVideo(msg.Chat.Id, videoPath);
        };
    }
    
    public static void UpdateOnScanCompleted(BotHandler botHandler, AutoScanApp autoScanApp, ILogger logger)
    {
        autoScanApp.OnScanCompleted = async () =>
        {
            logger.LogInformation("Scan completed at {At}", DateTime.Now);
            try
            {
                var images = autoScanApp.GetLastScanPictures();
                if (images.Length == 0)
                {
                    await botHandler.Update("No images found");
                    return;
                }
                await botHandler.Update($"Scan completed, found {images.Length} images");
                await botHandler.UpdatePhotos(images);    
            }catch(Exception ex)
            {
                logger.LogError(ex, "Error while sending message");
            }
        };
    }
}